==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebPageCancellableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebPageCancellableEventArgsDetailDescription } from "./WebPageCancellableEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPageCancellableEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPageCancellableEventArgsDetailDescriptionMetadata, _super);
    function WebPageCancellableEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPageCancellableEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPageCancellableEventArgsDetailDescriptionMetadata.a == null) {
            WebPageCancellableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPageCancellableEventArgsDetailDescriptionMetadata.c(WebPageCancellableEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebPageCancellableEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPageCancellableEventArgsDetailDescriptionMetadata.a);
    };
    WebPageCancellableEventArgsDetailDescriptionMetadata.c = function (a) {
        WebCancelableEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:PageCancellableEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Current", "Number:double");
        a.item("Next", "Number:double");
    };
    WebPageCancellableEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPageCancellableEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebPageCancellableEventArgsDetail", function () { return new WebPageCancellableEventArgsDetailDescription(); });
        a.z("WebPageCancellableEventArgsDetail", WebPageCancellableEventArgsDetailDescriptionMetadata.a);
    };
    WebPageCancellableEventArgsDetailDescriptionMetadata.$t = markType(WebPageCancellableEventArgsDetailDescriptionMetadata, 'WebPageCancellableEventArgsDetailDescriptionMetadata');
    WebPageCancellableEventArgsDetailDescriptionMetadata.a = null;
    return WebPageCancellableEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPageCancellableEventArgsDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPageCancellableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebPageCancellableEventArgsDetailDescription } from "./WebPageCancellableEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPageCancellableEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPageCancellableEventArgsDetailDescriptionMetadata, _super);
    function WebPageCancellableEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPageCancellableEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPageCancellableEventArgsDetailDescriptionMetadata.a == null) {
            WebPageCancellableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPageCancellableEventArgsDetailDescriptionMetadata.c(WebPageCancellableEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPageCancellableEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPageCancellableEventArgsDetailDescriptionMetadata.a);
    };
    WebPageCancellableEventArgsDetailDescriptionMetadata.c = function (a) {
        WebCancelableEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:PageCancellableEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Current", "Number:double");
        a.item("Next", "Number:double");
    };
    WebPageCancellableEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPageCancellableEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebPageCancellableEventArgsDetail", function () { return new WebPageCancellableEventArgsDetailDescription(); });
        a.ab("WebPageCancellableEventArgsDetail", WebPageCancellableEventArgsDetailDescriptionMetadata.a);
    };
    WebPageCancellableEventArgsDetailDescriptionMetadata.$t = markType(WebPageCancellableEventArgsDetailDescriptionMetadata, 'WebPageCancellableEventArgsDetailDescriptionMetadata');
    WebPageCancellableEventArgsDetailDescriptionMetadata.a = null;
    return WebPageCancellableEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPageCancellableEventArgsDetailDescriptionMetadata };
